---
title: <span class="badge object-type-scalar"></span> Gradian
---
# <span class="badge object-type-scalar"></span> Gradian

Angle: Gradian

## Definition

```python
# Angle: Gradian
Gradian: typing.Literal["grad"] = "grad"
```
